==> aws-cdk.assertions-1.139.0.tar.gz: package/lib/capture.d.ts <==
import { Matcher, MatchResult } from './matcher';
/**
 * Capture values while matching templates.
 *
 * Using an instance of this class within a Matcher will capture the matching value.
 * The `as*()` APIs on the instance can be used to get the captured value.
 *
 * @stability stable
 */
export declare class Capture extends Matcher {
    private readonly pattern?;
    /**
     * A name for the matcher.
     *
     * This is collected as part of the result and may be presented to the user.
     *
     * @stability stable
     */
    readonly name: string;
    /** @internal */
    _captured: any[];
    private idx;
    /**
     * Initialize a new capture.
     *
     * @param pattern a nested pattern or Matcher.
     * @stability stable
     */
    constructor(pattern?: any);
    /**
     * Test whether a target matches the provided pattern.
     *
     * Every Matcher must implement this method.
     * This method will be invoked by the assertions framework. Do not call this method directly.
     *
     * @stability stable
     */
    test(actual: any): MatchResult;
    /**
     * When multiple results are captured, move the iterator to the next result.
     *
     * @returns true if another capture is present, false otherwise
     * @stability stable
     */
    next(): boolean;
    /**
     * Retrieve the captured value as a string.
     *
     * An error is generated if no value is captured or if the value is not a string.
     *
     * @stability stable
     */
    asString(): string;
    /**
     * Retrieve the captured value as a number.
     *
     * An error is generated if no value is captured or if the value is not a number.
     *
     * @stability stable
     */
    asNumber(): number;
    /**
     * Retrieve the captured value as a boolean.
     *
     * An error is generated if no value is captured or if the value is not a boolean.
     *
     * @stability stable
     */
    asBoolean(): boolean;
    /**
     * Retrieve the captured value as an array.
     *
     * An error is generated if no value is captured or if the value is not an array.
     *
     * @stability stable
     */
    asArray(): any[];
    /**
     * Retrieve the captured value as a JSON object.
     *
     * An error is generated if no value is captured or if the value is not an object.
     *
     * @stability stable
     */
    asObject(): {
        [key: string]: any;
    };
    private validate;
    private reportIncorrectType;
}

==> aws-cdk.assertions-1.161.0.tar.gz: package/lib/capture.d.ts <==
import { Matcher, MatchResult } from './matcher';
/**
 * Capture values while matching templates.
 * Using an instance of this class within a Matcher will capture the matching value.
 * The `as*()` APIs on the instance can be used to get the captured value.
 */
export declare class Capture extends Matcher {
    private readonly pattern?;
    readonly name: string;
    /** @internal */
    _captured: any[];
    private idx;
    /**
     * Initialize a new capture
     * @param pattern a nested pattern or Matcher.
     * If a nested pattern is provided `objectLike()` matching is applied.
     */
    constructor(pattern?: any);
    test(actual: any): MatchResult;
    /**
     * When multiple results are captured, move the iterator to the next result.
     * @returns true if another capture is present, false otherwise
     */
    next(): boolean;
    /**
     * Retrieve the captured value as a string.
     * An error is generated if no value is captured or if the value is not a string.
     */
    asString(): string;
    /**
     * Retrieve the captured value as a number.
     * An error is generated if no value is captured or if the value is not a number.
     */
    asNumber(): number;
    /**
     * Retrieve the captured value as a boolean.
     * An error is generated if no value is captured or if the value is not a boolean.
     */
    asBoolean(): boolean;
    /**
     * Retrieve the captured value as an array.
     * An error is generated if no value is captured or if the value is not an array.
     */
    asArray(): any[];
    /**
     * Retrieve the captured value as a JSON object.
     * An error is generated if no value is captured or if the value is not an object.
     */
    asObject(): {
        [key: string]: any;
    };
    private validate;
    private reportIncorrectType;
}
